@@ -3,7 +3,8 @@ LoadPackages <- function(repo="http://cran.r-project.org") {
   # package is unavailable on the local computer an attempt is made to
   # acquire the package from CRAN using an existing network connection.
 
-  require.pkgs <- c("tcltk", "sp", "gpclib", "rgl", "MBA", "tripack")
+  require.pkgs <- c("tcltk", "sp", "gpclib", "rgl", "MBA", "tripack",
+                    "RColorBrewer")
   suggest.pkgs <- c("rgdal")
 
   # Packages that may be useful for future work:
